@@ -32,7 +32,7 @@ while [[ "$1" != "" ]];
 do
    FILE=`realpath "$1"`
    GENRES=$(imdb-get -f "$FILE" -g | cut -d: -f2)
-   IFS=' /'
+   IFS=' /|'
    for i in $GENRES; do
       mkdir -p "$TARGET/$i"
       if [[ ! -e "$TARGET/$i/`basename "$FILE"`" ]]; then
